==> sign-center-api-0.0.26-mgj1-20180808.082814-3-sources.jar: cn/com/duiba/sign/center/api/remoteservice/signpet/RemoteSignPetToyService.java <==
package cn.com.duiba.sign.center.api.remoteservice.signpet;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.consumer.center.api.dto.ConsumerDto;
import cn.com.duiba.developer.center.api.domain.dto.AppSimpleDto;
import cn.com.duiba.sign.center.api.dto.SignPetActivityToyDto;
import cn.com.duiba.sign.center.api.dto.SignPetPurchasedToyDto;
import cn.com.duiba.sign.center.api.enums.signpet.ExchangeTypeEnum;
import cn.com.duiba.sign.center.api.params.ToyPositionUseParam;

import java.util.List;

/**
 * @author liugq
 * @date created in 2018/5/15
 * @description: 宠物道具
 */
@AdvancedFeignClient
public interface RemoteSignPetToyService {

    /**
     * 道具兑换
     * @param app
     * @param consumerDto
     * @param actToyId
     * @param ip
     * @param transfer
     */
    void createExchangeOrder(AppSimpleDto app, ConsumerDto consumerDto, Long actToyId, ExchangeTypeEnum exchangeType, String ip, String transfer) throws BizException;

    /**
     * 使用道具(外来宠物)
     */
    void useToyForWanderPet(Long actId,Long consumerId,List<ToyPositionUseParam> param) throws BizException;

    /**
     * 查询道具商店展示的道具
     * @param actId
     * @return
     */
    List<SignPetActivityToyDto> selectDuibaToy(Long actId);

    /**
     * 查询宠物拥有的道具
     * @param petId
     * @return
     */
    List<SignPetPurchasedToyDto> selectUserToy(Long petId,Long consumerId);

    /**
     * 查询宠物正在使用的道具
     * @param petId
     * @return
     */
    List<SignPetPurchasedToyDto> selectUsingToy(Long petId,Long consumerId);
}

==> sign-center-api-0.0.29-mgj3-20180813.115947-1-sources.jar: cn/com/duiba/sign/center/api/remoteservice/signpet/RemoteSignPetToyService.java <==
package cn.com.duiba.sign.center.api.remoteservice.signpet;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.consumer.center.api.dto.ConsumerDto;
import cn.com.duiba.developer.center.api.domain.dto.AppSimpleDto;
import cn.com.duiba.sign.center.api.dto.SignPetActivityToyDto;
import cn.com.duiba.sign.center.api.dto.SignPetPurchasedToyDto;
import cn.com.duiba.sign.center.api.enums.creditssign.SignActivityTypeEnum;
import cn.com.duiba.sign.center.api.enums.signpet.ExchangeTypeEnum;
import cn.com.duiba.sign.center.api.enums.signpet.ToyTypeEnum;
import cn.com.duiba.sign.center.api.params.ToyPositionUseParam;

import java.util.List;

/**
 * @author liugq
 * @date created in 2018/5/15
 * @description: 宠物道具
 */
@AdvancedFeignClient
public interface RemoteSignPetToyService {

    /**
     * 道具兑换
     * @param app
     * @param consumerDto
     * @param actToyId
     * @param ip
     * @param transfer
     */
    void createExchangeOrder(AppSimpleDto app, ConsumerDto consumerDto, Long actToyId,String ip, String transfer) throws BizException;

    /**
     * 使用道具(外来宠物)
     */
    void useToyForWanderPet(Long actId,Long consumerId,List<ToyPositionUseParam> param) throws BizException;

    /**
     * 查询道具商店展示的道具
     * @param actId
     * @return
     */
    List<SignPetActivityToyDto> selectActToy(Long actId, SignActivityTypeEnum actType);

    /**
     * 查询宠物拥有的道具
     * @param petId
     * @return
     */
    List<SignPetPurchasedToyDto> selectUserToy(Long petId, Long consumerId, ToyTypeEnum toyType);

    /**
     * 查询宠物正在使用的道具
     * @param petId
     * @return
     */
    List<SignPetPurchasedToyDto> selectUsingToy(Long petId,Long consumerId);
}
